defmodule OpWeb.Router do
  use OpWeb, :router

  pipeline :browser do
    plug :accepts, ["html"]
    plug :fetch_session
    plug :fetch_live_flash
    plug :put_root_layout, html: {OpWeb.Layouts, :root}
    plug :protect_from_forgery
    plug :put_secure_browser_headers
  end

  pipeline :api do
    plug :accepts, ["json"]
  end

  scope "/", OpWeb do pipe_through :browser
    live "/", Domain.Index, :index, as: :domain
    get "/gear", PageController, :gear
  end

  scope "/gram", OpWeb do pipe_through :browser
    live "/:base", Gram.Base, :index, as: :gram
    live "/:base/*address", Gram.Node, :node, as: :gram
  end

  scope "/queri", OpWeb do pipe_through :browser
    live "/", QueriLive.Index, :index
    live "/new", QueriLive.Index, :new
    live "/:id/edit", QueriLive.Index, :edit
    live "/:id", QueriLive.Show, :show
    live "/:id/show/edit", QueriLive.Show, :edit
  end

  scope "/chronicle", OpWeb do pipe_through :browser
    get "/", Course, to: "/"
    live "/:key", Chronicle.Show, :show, as: :chronicle
  end

  scope "/issue", OpWeb do pipe_through :browser
    ~w[ / /:key ]
    |> Enum.each(& get &1, Course, to: "/")
  end

  scope "/page", OpWeb do pipe_through :browser
    get "/", PageController, :index
    get "/:key", PageController, :show
  end

  # Other scopes may use custom stacks.
  # scope "/api", OpWeb do
  #   pipe_through :api
  # end

  # Enable LiveDashboard and Swoosh mailbox preview in development
  if Application.compile_env(:op, :dev_routes) do
    # If you want to use the LiveDashboard in production, you should put
    # it behind authentication and allow only admins to access it.
    # If your application does not have an admins-only section yet,
    # you can use Plug.BasicAuth to set up some basic authentication
    # as long as you are also using SSL (which you should anyway).
    import Phoenix.LiveDashboard.Router

    scope "/dev" do
      pipe_through :browser

      live_dashboard "/dashboard", metrics: OpWeb.Telemetry
      # forward "/mailbox", Plug.Swoosh.MailboxPreview
    end
  end
end
